==> tuia-news-center-api-0.0.16-xt-20180409.080828-3-sources.jar: cn/com/duiba/tuia/news/center/dto/req/UserActionStatisticDto.java <==
package cn.com.duiba.tuia.news.center.dto.req;

import java.util.Date;

public class UserActionStatisticDto {

    /** 命中规则 */
    private String rules;
    /** 用户 id */
    private Long   userId;
    /** 关联的设备数 */
    private Long   deviceCount;
    /** 使用时间,单位分 */
    private Long   usingTime;
    /** 新闻点击数 */
    private Long   clickNewsPv;
    /** 获取的金币数 */
    private Long   balance;
    /** 申请提现次数 */
    private Long   applyFeeTimes;
    /** 提现通过次数 */
    private Long   passFeeTimes;
    /** 注册时间 */
    private Date   registerDate;

    public String getRules() {
        return rules;
    }

    public void setRules(String rules) {
        this.rules = rules;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getDeviceCount() {
        return deviceCount;
    }

    public void setDeviceCount(Long deviceCount) {
        this.deviceCount = deviceCount;
    }

    public Long getUsingTime() {
        return usingTime;
    }

    public void setUsingTime(Long usingTime) {
        this.usingTime = usingTime;
    }

    public Long getClickNewsPv() {
        return clickNewsPv;
    }

    public void setClickNewsPv(Long clickNewsPv) {
        this.clickNewsPv = clickNewsPv;
    }

    public Long getBalance() {
        return balance;
    }

    public void setBalance(Long balance) {
        this.balance = balance;
    }

    public Long getApplyFeeTimes() {
        return applyFeeTimes;
    }

    public void setApplyFeeTimes(Long applyFeeTimes) {
        this.applyFeeTimes = applyFeeTimes;
    }

    public Long getPassFeeTimes() {
        return passFeeTimes;
    }

    public void setPassFeeTimes(Long passFeeTimes) {
        this.passFeeTimes = passFeeTimes;
    }

    public Date getRegisterDate() {
        return registerDate;
    }

    public void setRegisterDate(Date registerDate) {
        this.registerDate = registerDate;
    }
}

==> tuia-news-center-api-0.0.34-xt4-20180522.114858-1-sources.jar: cn/com/duiba/tuia/news/center/dto/req/UserActionStatisticDto.java <==
package cn.com.duiba.tuia.news.center.dto.req;

import java.util.Date;

public class UserActionStatisticDto {

    /** 命中规则 */
    private String rules;
    /** 用户 id */
    private Long   userId;
    /** 关联的设备数 */
    private Long   deviceCount;
    /** 使用时间,单位分 */
    private Long   usingTime;
    /** 新闻点击数 */
    private Long   clickNewsPv;
    /** 获取的金币数 */
    private Long   balance;
    /** 申请提现次数 */
    private Long   applyFeeTimes;
    /** 提现通过次数 */
    private Long   passFeeTimes;
    /** 注册时间 */
    private Date   registerDate;
    /**支付宝账号使用次数*/
    private Long   alipayTimes;

    public Long getAlipayTimes() {
        return alipayTimes;
    }

    public void setAlipayTimes(Long alipayTimes) {
        this.alipayTimes = alipayTimes;
    }

    public String getRules() {
        return rules;
    }

    public void setRules(String rules) {
        this.rules = rules;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getDeviceCount() {
        return deviceCount;
    }

    public void setDeviceCount(Long deviceCount) {
        this.deviceCount = deviceCount;
    }

    public Long getUsingTime() {
        return usingTime;
    }

    public void setUsingTime(Long usingTime) {
        this.usingTime = usingTime;
    }

    public Long getClickNewsPv() {
        return clickNewsPv;
    }

    public void setClickNewsPv(Long clickNewsPv) {
        this.clickNewsPv = clickNewsPv;
    }

    public Long getBalance() {
        return balance;
    }

    public void setBalance(Long balance) {
        this.balance = balance;
    }

    public Long getApplyFeeTimes() {
        return applyFeeTimes;
    }

    public void setApplyFeeTimes(Long applyFeeTimes) {
        this.applyFeeTimes = applyFeeTimes;
    }

    public Long getPassFeeTimes() {
        return passFeeTimes;
    }

    public void setPassFeeTimes(Long passFeeTimes) {
        this.passFeeTimes = passFeeTimes;
    }

    public Date getRegisterDate() {
        return registerDate;
    }

    public void setRegisterDate(Date registerDate) {
        this.registerDate = registerDate;
    }
}
